==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QThreadPool_shell.h <==
#ifndef QTHREADPOOL_SHELL_H
#define QTHREADPOOL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qconfig.h>
#if QT_CONFIG(thread)
#include <QtCore/qthreadpool.h>
#endif //QT_CONFIG(thread)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qrunnable.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JObjectWrapper>
#include <utils_p.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(thread)

class QThreadPool_shell : public QThreadPool, public QtJambiShellInterface
{
public:
    QThreadPool_shell(QObject* parent0 = nullptr);
    ~QThreadPool_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QThreadPool_access : public QThreadPool
{
};

#endif // QT_CONFIG(thread)
#endif // QTHREADPOOL_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QThreadPool_shell.h <==
#ifndef QTHREADPOOL_SHELL_H
#define QTHREADPOOL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qconfig.h>
#if QT_CONFIG(thread)
#include <QtCore/qthreadpool.h>
#endif //QT_CONFIG(thread)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qrunnable.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/JObjectWrapper>
#include <utils_p.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(thread)

class QThreadPool_shell : public QThreadPool, public QtJambiShellInterface
{
public:
    QThreadPool_shell(QObject* parent0 = nullptr);
    ~QThreadPool_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QThreadPool_mshell;
    friend class QThreadPool_oshell;
};


class QThreadPool_mshell : public QThreadPool_shell
{
public:
    using QThreadPool_shell::QThreadPool_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QThreadPool_oshell : public QThreadPool_mshell
{
public:
    using QThreadPool_mshell::QThreadPool_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QThreadPool_access : public QThreadPool
{
};

#endif // QT_CONFIG(thread)
#endif // QTHREADPOOL_SHELL_H
